import math
import time

import Adafruit_GPIO.SPI as SPI
import Adafruit_SSD1306

import Image
import ImageFont
import ImageDraw


class adafruitOLED:
	def __init__(self):
		# Raspberry Pi pin configuration:
		RST = 24
		# Note the following are only used with SPI:
		DC = 23
		SPI_PORT = 0
		SPI_DEVICE = 0
		
		# 128x64 display with hardware SPI:
		self.disp = Adafruit_SSD1306.SSD1306_128_64(rst=RST, dc=DC, spi=SPI.SpiDev(SPI_PORT, SPI_DEVICE, max_speed_hz=8000000))


		self.disp.begin()	# Initialize library.
		
		self.width = self.disp.width
		self.height = self.disp.height

		# Clear display.
		self.disp.clear()
		self.disp.display()
		
		# Create image buffer.
		# Make sure to create image with mode '1' for 1-bit color.
		self.image = Image.new('1', (self.width, self.height))
	
		# Create drawing object.
		self.draw = ImageDraw.Draw(self.image)
		
		self.mode = 0
		self.speed = 0
		self.altitude = 0
		self.heading = 0
		
	def drawBuffer(self):
		# Draw the image buffer.
		self.disp.image(self.image)
		self.disp.display()
		
	def displayText(self,msg, size=16):
		font = ImageFont.truetype('/home/pi/upheavtt.ttf', size)
		# Clear image buffer by drawing a black filled box.
		self.draw.rectangle((0,0,self.width,self.height), outline=0, fill=0)
		
		w, h = self.draw.textsize(msg, font=font)
		self.draw.text(((self.width-w)/2,(self.height-h)/2), msg, font=font, fill=255)
		self.drawBuffer()
	
	def displaySpeed(self, speed):
		msg = str(speed) + " mph"
		self.displayText(msg, 32)
		
	def displayMode(self):
		mode = self.mode
		if mode == 0:
			self.displayText("No GPS")
		elif mode == 1:
			self.displaySpeed(self.speed)
		elif mode == 2:
			self.displayText("%s m" % self.altitude, 32)
		elif mode == 3:
			self.displayText("%s deg" % self.heading, 32)
	

		
if __name__ == '__main__':

	print 'Press Ctrl-C to quit.'
	
	display = adafruitOLED()
	num = 50
	while True:
		num = num + 1
		
		if num > 115:
			num = 40
		#display.displaySpeed(num)
		display.displayText("No GPS")
		time.sleep(0.05)
