import io
import os
import time
import threading
import thread
import signal
import sys
import subprocess
import serial
from datetime import datetime
import pytz

# PageMac GPS Raspberry Pi 10 Hz GPS / IMU Data Logger
# https://www.pagemac.com/projects/rpi_gps_imu
# written by Daniel Smith, 2015-2019

# this code is Python 2.7

# this variation of code only writes out the raw GPS NMEA strings and does not use the IMU

class gpsSerial:
	serialNextDataDibsFlag = 0
	serialNextData = ""
	
	def __init__(self, device, baudrate):
		self.device = device
		self.baudrate = baudrate
		self.portOpen = False
		self.serialObj = serial.Serial(self.device, self.baudrate, timeout=0.05)
	
	
	def open(self):
		self.serialObj.close()
		self.serialObj.open()
		self.portOpen = self.serialObj.isOpen() 

	def close(self):
		self.portOpen = False
		self.serialObj.close()
		
	def readSerialThread(self):	# thread runs in the background to constantly read data from the serial port
		global logFile
		while (self.portOpen):	# do this forever
			try:
				#data = self.serialObj.read(1000);				#read serial port data
				line = self.serialObj.readline()
			except KeyboardInterrupt:				# on CTL-C
				print " - Keyboard interrupt!!!"
				break
			except e:
				print " - readSerial error: %r" % e
				pass

			if line != "":
				#print line.replace("\r\n", "")
				#gps_data = line.split(",")
				#print gps_data[0]
				logFile.write(line)

	def sendLine(self, cmd):		# write a line to serial, and eppend \r\n
		self.serialObj.write(cmd + "\r\n")
		
print ">EPOS startup"

logFilePath = "/home/pi/" + datetime.now(pytz.timezone('US/Eastern')).strftime("%Y-%m-%d_%H-%M-%S") + ".gps"
print ">Creating log " + logFilePath
logFile = open(logFilePath,'a+')	# create a new file

		
print ">Init GPS"
mySerial = gpsSerial("/dev/ttyAMA0", 9600)
mySerial.open()
time.sleep(.5)
print ">Configuring GPS"
mySerial.sendLine("$PMTK251,115200*1F\r\n"); # tell the gps to switch to 115200 baud 
mySerial.close()
mySerial.serialObj.baudrate = 115200	# change our serial port baud rate to 115200
mySerial.baudrate = 115200
mySerial.open()
thread.start_new_thread(mySerial.readSerialThread, ())	# start a thread to read the serial port constantly
time.sleep(.5)

mySerial.sendLine("$PMTK314,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0*28")	# tell the GPS to print GPRMC and GGA outputs only
mySerial.sendLine("$PMTK220,1000*1F")	# set GPS update rate to 1 Hz
#mySerial.sendLine("$PMTK220,100*2F") # set GPS update rate to 10 Hz



exitFlag = 0


print ">Main loop"
try:
	while 1:
		#time.sleep(.1)
		# everything is handled in other threads...
		if exitFlag == 1:
			break

except KeyboardInterrupt:	
	print " - Keyboard interrupt!"
except e:
	print " - Main except: %r" % e
	
try:
	logFile.close() 
	mySerial.close()
	#printMsg("Exiting... " + str(sys.exc_info()[0]))
except e:
	print " - Exit except: %r" % e
os._exit(1)